BuildCommand

Struct BuildCommand 

pub struct BuildCommand { /* private fields */ }
Executes build of the memex executable meme which produces meme “binary”.

It does so by invoking cargo build and then post processing the final binary.

Implementations

Source

impl BuildCommand

pub fn run(&self) -> Result<BuildOutput>

execute the build command